Module discovery

Module discovery 

CI project discovery utilities.

Provides functions for discovering CUE modules and projects for CI operations. Projects can be discovered from the current directory or from an already-evaluated module.

Uses discovery-based evaluation: finds all env.cue files and evaluates each directory individually with recursive: false, avoiding CUE’s ./...:package pattern which can hang when directories contain mixed packages.

Functions

evaluate_module_from_cwd
Evaluate the CUE module from the current working directory.
find_cue_module_root
Find the CUE module root by walking up from start looking for cue.mod/ directory.