Module metrics

Module metrics 

Cache Metrics

Provides metrics collection for cache operations and task execution. Metrics are exposed in formats compatible with Prometheus and OpenTelemetry.

Structs

CacheMetrics
Cache metrics collector

Enums

RestoreErrorType
Error types for restore failures

Functions

global_metrics
Get or initialize global cache metrics