pub struct IntermediateRepresentation {
pub version: String,
pub pipeline: PipelineMetadata,
pub runtimes: Vec<Runtime>,
pub tasks: Vec<Task>,
}Expand description
Root IR document
Fields
version: StringIR version (always “1.5”)
pipeline: PipelineMetadataPipeline metadata
runtimes: Vec<Runtime>Runtime environment definitions
tasks: Vec<Task>Task definitions (includes both regular tasks and phase tasks)
Implementations
Sourceimpl IntermediateRepresentation
impl IntermediateRepresentation
Sourcepub fn phase_tasks(&self, stage: BuildStage) -> impl Iterator<Item = &Task>
pub fn phase_tasks(&self, stage: BuildStage) -> impl Iterator<Item = &Task>
Get all tasks belonging to a specific phase (unified model).
Returns an iterator over tasks that have phase set to the given stage.
These are tasks contributed by CUE contributors.
Sourcepub fn regular_tasks(&self) -> impl Iterator<Item = &Task>
pub fn regular_tasks(&self) -> impl Iterator<Item = &Task>
Get all regular tasks (not phase tasks).
Returns an iterator over tasks that have no phase set. These are the main pipeline tasks defined in the project.
Sourcepub fn sorted_phase_tasks(&self, stage: BuildStage) -> Vec<&Task>
pub fn sorted_phase_tasks(&self, stage: BuildStage) -> Vec<&Task>
Get phase tasks sorted by priority (lower = earlier).
Collects phase tasks into a Vec and sorts them by priority. Uses priority 10 as default if not specified.