Cache Backend Abstraction
Defines the CacheBackend trait for pluggable cache implementations.
Supports both local file-based caching and remote Bazel RE v2 caching.
Structs
- Cache
Entry - Stored task execution result
- Cache
Lookup Result - Result of a cache lookup
- Cache
Output - Output artifact to store in cache
Enums
- Backend
Error - Error types for cache backend operations
Traits
- Cache
Backend - Cache backend trait for pluggable cache implementations
Functions
- policy_
allows_ read - Determine if cache read is allowed for a policy
- policy_
allows_ write - Determine if cache write is allowed for a policy
Type Aliases
- Backend
Result - Result type for cache backend operations