Cache Metrics
Provides metrics collection for cache operations and task execution. Metrics are exposed in formats compatible with Prometheus and OpenTelemetry.
Structs
- Cache
Metrics - Cache metrics collector
Enums
- Restore
Error Type - Error types for restore failures
Functions
- global_
metrics - Get or initialize global cache metrics